@@ -106,6 +106,8 @@ class MyProcess(object):
         while True:
             if self._start_index >= len(data):
                 break
+            if self._end_index > len(data):
+                self._end_index = len(data)
             threads = []
             for i in range(self._start_index, self._end_index):
                 arg = data[i]
@@ -166,7 +168,7 @@ if __name__ == '__main__':
 
     while True:
         arr = []
-        for i in range(20):
+        for i in range(22):
             arr.append(i)
 
         ret = process.begin_v2(arr, go_v2, each, finish)
